@@ -41,8 +41,6 @@
 
 #define KDNSSD_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KDNSSD_NO_DEPRECATED) && !defined(KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KDNSSD_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDNSSD_NO_DEPRECATED
-#  define KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
 #endif
 #ifdef KDNSSD_NO_DEPRECATED_WARNINGS
 #  define KDNSSD_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDNSSD_DEPRECATED_WARNINGS_SINCE KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDNSSD_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KDNSSD_DEPRECATED_WARNINGS_SINCE 0x56b00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KDNSSD_DEPRECATED
-#  define KDNSSD_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KDNSSD_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KDNSSD_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KDNSSD_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
